import { ContentTypeEnum } from '@/enums/httpEnums'
import { defHttp } from '@/utils/axios/index'
import type { DictDetailResultDto, DictListParamsDto, DictListResultDto } from './model/dictModel'
import type { ApiResult, ApiResultRecord } from '../model/baseModel'

enum Api {
  DICT_PAGE = '/dict/page',
  DICT_FINDBYID = '/dict/findDictItemsByDictCode',
  DICT_FINDBYCODE = '/dict/findDictByDictCode'
}

/**
 * 条件查询码表
 * @param params
 * @returns
 */
export const apiGetDictList = (params: DictListParamsDto) => {
  return defHttp.get<ApiResult<ApiResultRecord<DictListParamsDto[]>>>({
    url: Api.DICT_PAGE,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    },
    params
  })
}

/**
 * 根据码表编码查询
 * @param dictCode
 * @returns
 */
export const apiGetDictByCode = (dictCode: string) => {
  return defHttp.get<ApiResult<DictListResultDto[]>>({
    url: Api.DICT_FINDBYCODE,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    },
    params: { dictCode }
  })
}

/**
 * 根据id查询码表及明细表
 * @param dictCode
 * @returns
 */
export const apiDictFindById = (dictCode: string) => {
  return defHttp.get<ApiResult<DictDetailResultDto[]>>({
    url: Api.DICT_FINDBYID,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    },
    params: { dictCode }
  })
}
