import { ContentTypeEnum } from '@/enums/httpEnums'
import { defHttp } from '@/utils/axios/index'
import type { ApiResult } from '../model/baseModel'
import type { ResourceFieldDto, ResourceRepositoryTreeDto } from './model/repositoryModel'

export type ResourceSaveParamsDto = Omit<ResourceRepositoryTreeDto, 'childNode'>

enum Api {
  /*查询全部资源 */
  REPOSITORY_LIST = '/resource/findList',
  /*根据资源类型id，查询资源字段 */
  GET_RESOURCE_FIELD = '/resourceField/getResourceField',
  /*根据资源类型id，获取资源值 */
  GET_RESOURCE_FIELD_VALUE = '/resourceField/getResourceFieldValue',
  /* 新增资源类型时，根据对象的父类表名，返回父类和超类及所属的字段 */
  FIND_PARENT_RESOURCE = '/resource/findParentResourceTypeAndFields',
  /* 保存资源库 */
  RESOURCE_SAVE = '/resource/save',
  /*修改-查看资源类型时，根据当前表名，返回自己和父类和超类及所属的字段 */
  FIND_RESOURCE_TYPE_FIELDS = '/resource/findResourceTypeAndFields',
  /*根据id删除资源库 */
  DELETE_RESOURCE = '/resource/delete'
}

export const apiGetRepositoryList = () => {
  return defHttp.get<ApiResult<ResourceRepositoryTreeDto[]>>({
    url: Api.REPOSITORY_LIST,
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiGetResourceField = (resourceTypeId: string) => {
  return defHttp.get<ApiResult<ResourceFieldDto[]>>({
    url: Api.GET_RESOURCE_FIELD,
    params: { resourceTypeId },
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiGetResourceFieldValue = (resourceTypeId: string) => {
  return defHttp.get<ApiResult<Recordable[]>>({
    url: Api.GET_RESOURCE_FIELD_VALUE,
    params: { resourceTypeId },
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiFindParentResource = (tableName: string) => {
  return defHttp.get<ApiResult<ResourceRepositoryTreeDto>>({
    url: Api.FIND_PARENT_RESOURCE,
    params: { tableName },
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiResourceSave = (data: ResourceSaveParamsDto) => {
  return defHttp.post<ApiResult<ResourceRepositoryTreeDto>>({
    url: Api.RESOURCE_SAVE,
    data
  })
}

export const apiFindResourceTypeFields = (tableName: string) => {
  return defHttp.get<ApiResult<ResourceRepositoryTreeDto>>({
    url: Api.FIND_RESOURCE_TYPE_FIELDS,
    params: { tableName },
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}

export const apiDeleteResource = (id: string) => {
  return defHttp.delete<ApiResult<Recordable>>({
    url: Api.DELETE_RESOURCE,
    params: { id },
    headers: {
      'Content-Type': ContentTypeEnum.FORM_URLENCODED
    }
  })
}
