import type { ResourceRepositoryTreeDto } from '@/api/resource/model/repositoryModel'
import { apiDeleteResource, apiGetRepositoryList } from '@/api/resource/repository'
import { onMounted, reactive, ref, unref, watch } from 'vue'
import mitter from '@/utils/eventBus'
import { ElMessage, type ElTree, type TreeNode } from 'element-plus'

export function useRepositoryTree() {
  const open = ref(false)
  const searchText = ref('')
  const treeLoading = ref(false)
  const selectedKey = ref<string | number>('')
  const treeRef = ref<InstanceType<typeof ElTree>>()
  const treeList = ref<ResourceRepositoryTreeDto[]>([])
  const selectedNodeData = reactive<Recordable>({})
  const openNode = reactive<Recordable>({})
  const fieldNames = reactive({
    children: 'childNode',
    title: 'resourceTableTitle',
    key: 'resourceTypeId'
  })

  watch(searchText, (val) => {
    treeRef.value?.filter(val)
  })

  const treeAddNode = (data: any) => treeRef.value?.append(data, openNode.resourceTypeId)
  const treeRemoveNode = async (data: any) => {
    try {
      await apiDeleteResource(data.resourceTypeId)
      treeRef.value?.remove(data)
      ElMessage.success('删除成功！')
    } catch {}
  }

  const filterNode = (value: string, data: Recordable) => {
    if (!value) return true
    return data.resourceTableTitle.includes(value)
  }

  const getTreeList = async () => {
    const { result } = await apiGetRepositoryList()
    treeList.value = result
    // 设置默认选中第一个
    onSelect([result[0]])
  }

  const onSuccess = (data) => treeAddNode(data)

  const onSelect = (node: any) => {
    node && Object.assign(selectedNodeData, unref(node))
    selectedKey.value = node.resourceTypeId
    // 触发 表格 查询
    mitter.emit('treeSelect', {
      key: unref(selectedKey),
      node: unref(node)
    })
  }

  const onContextMenuClick = (key: any, data: any) => {
    switch (key) {
      case 'add':
        Object.assign(unref(openNode), unref(data))
        open.value = true
        break
      case 'del':
        treeRemoveNode(data)
        break
      case 'update':
        open.value = true
        break
    }
  }

  onMounted(async () => {
    treeLoading.value = true
    await getTreeList()
    treeLoading.value = false
  })

  return {
    open,
    treeRef,
    treeLoading,
    searchText,
    openNode,
    fieldNames,
    treeList,
    selectedKey,
    onSuccess,
    onSelect,
    filterNode,
    onContextMenuClick
  }
}
